@@ -1,14 +1,13 @@
 import logging
 from typing import Iterator, NoReturn
-
+import itertools
 import pandas as pd
 from tiny_blocks.base import BaseBlock
+from tiny_blocks.load.base import KwargsBase
 from tiny_blocks.transform.base import TransformBase
-from tiny_blocks.load.base import LoadBase, KwargsBase
-from typing import TYPE_CHECKING
+from tiny_blocks.load.base import LoadBase
+from tiny_blocks.pipeline import Pipe, FanOut
 
-if TYPE_CHECKING:
-    from tiny_blocks.pipeline import Pipe
 
 __all__ = ["ExtractBase", "KwargsExtractBase"]
 
@@ -42,18 +41,21 @@ class ExtractBase(BaseBlock):
         raise NotImplementedError
 
     def __rshift__(
-        self,
-        next: TransformBase | LoadBase,
-    ) -> NoReturn | "Pipe":
+        self, next: TransformBase | LoadBase | FanOut
+    ) -> NoReturn | Pipe:
         """
         The `>>` operator for the tiny-blocks library.
         """
         if isinstance(next, TransformBase):
             source = next.get_iter(source=self.get_iter())
-            from tiny_blocks.pipeline import Pipe
-
             return Pipe(source)
         elif isinstance(next, LoadBase):
             return next.exhaust(source=self.get_iter())
+        elif isinstance(next, FanOut):
+            # n sources = a source per each load block + 1 for the next pipe
+            n = len(next.load_blocks) + 1
+            source, *sources = itertools.tee(self.get_iter(), n)
+            next.exhaust(*sources)
+            return Pipe(source=source)
         else:
             raise ValueError("Unsupported Block Type")
